Documentation
¶
Index ¶
- type CurrentLibraryConfig
- func (*CurrentLibraryConfig) Descriptor() ([]byte, []int)
- func (m *CurrentLibraryConfig) GetConfig() *v11.TraceConfig
- func (m *CurrentLibraryConfig) GetNode() *v1.Node
- func (*CurrentLibraryConfig) ProtoMessage()
- func (m *CurrentLibraryConfig) Reset()
- func (m *CurrentLibraryConfig) String() string
- func (m *CurrentLibraryConfig) XXX_DiscardUnknown()
- func (m *CurrentLibraryConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *CurrentLibraryConfig) XXX_Merge(src proto.Message)
- func (m *CurrentLibraryConfig) XXX_Size() int
- func (m *CurrentLibraryConfig) XXX_Unmarshal(b []byte) error
- type ExportTraceServiceRequest
- func (*ExportTraceServiceRequest) Descriptor() ([]byte, []int)
- func (m *ExportTraceServiceRequest) GetNode() *v1.Node
- func (m *ExportTraceServiceRequest) GetResource() *v12.Resource
- func (m *ExportTraceServiceRequest) GetSpans() []*v11.Span
- func (*ExportTraceServiceRequest) ProtoMessage()
- func (m *ExportTraceServiceRequest) Reset()
- func (m *ExportTraceServiceRequest) String() string
- func (m *ExportTraceServiceRequest) XXX_DiscardUnknown()
- func (m *ExportTraceServiceRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ExportTraceServiceRequest) XXX_Merge(src proto.Message)
- func (m *ExportTraceServiceRequest) XXX_Size() int
- func (m *ExportTraceServiceRequest) XXX_Unmarshal(b []byte) error
- type ExportTraceServiceResponse
- func (*ExportTraceServiceResponse) Descriptor() ([]byte, []int)
- func (*ExportTraceServiceResponse) ProtoMessage()
- func (m *ExportTraceServiceResponse) Reset()
- func (m *ExportTraceServiceResponse) String() string
- func (m *ExportTraceServiceResponse) XXX_DiscardUnknown()
- func (m *ExportTraceServiceResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ExportTraceServiceResponse) XXX_Merge(src proto.Message)
- func (m *ExportTraceServiceResponse) XXX_Size() int
- func (m *ExportTraceServiceResponse) XXX_Unmarshal(b []byte) error
- type UpdatedLibraryConfig
- func (*UpdatedLibraryConfig) Descriptor() ([]byte, []int)
- func (m *UpdatedLibraryConfig) GetConfig() *v11.TraceConfig
- func (m *UpdatedLibraryConfig) GetNode() *v1.Node
- func (*UpdatedLibraryConfig) ProtoMessage()
- func (m *UpdatedLibraryConfig) Reset()
- func (m *UpdatedLibraryConfig) String() string
- func (m *UpdatedLibraryConfig) XXX_DiscardUnknown()
- func (m *UpdatedLibraryConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *UpdatedLibraryConfig) XXX_Merge(src proto.Message)
- func (m *UpdatedLibraryConfig) XXX_Size() int
- func (m *UpdatedLibraryConfig) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CurrentLibraryConfig ¶
type CurrentLibraryConfig struct {
// This is required only in the first message on the stream or if the
// previous sent CurrentLibraryConfig message has a different Node (e.g.
// when the same RPC is used to configure multiple Applications).
Node *v1.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
// Current configuration.
Config *v11.TraceConfig `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*CurrentLibraryConfig) Descriptor ¶
func (*CurrentLibraryConfig) Descriptor() ([]byte, []int)
func (*CurrentLibraryConfig) GetConfig ¶
func (m *CurrentLibraryConfig) GetConfig() *v11.TraceConfig
func (*CurrentLibraryConfig) GetNode ¶
func (m *CurrentLibraryConfig) GetNode() *v1.Node
func (*CurrentLibraryConfig) ProtoMessage ¶
func (*CurrentLibraryConfig) ProtoMessage()
func (*CurrentLibraryConfig) Reset ¶
func (m *CurrentLibraryConfig) Reset()
func (*CurrentLibraryConfig) String ¶
func (m *CurrentLibraryConfig) String() string
func (*CurrentLibraryConfig) XXX_DiscardUnknown ¶
func (m *CurrentLibraryConfig) XXX_DiscardUnknown()
func (*CurrentLibraryConfig) XXX_Marshal ¶
func (m *CurrentLibraryConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*CurrentLibraryConfig) XXX_Merge ¶
func (m *CurrentLibraryConfig) XXX_Merge(src proto.Message)
func (*CurrentLibraryConfig) XXX_Size ¶
func (m *CurrentLibraryConfig) XXX_Size() int
func (*CurrentLibraryConfig) XXX_Unmarshal ¶
func (m *CurrentLibraryConfig) XXX_Unmarshal(b []byte) error
type ExportTraceServiceRequest ¶
type ExportTraceServiceRequest struct {
// This is required only in the first message on the stream or if the
// previous sent ExportTraceServiceRequest message has a different Node (e.g.
// when the same RPC is used to send Spans from multiple Applications).
Node *v1.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
// A list of Spans that belong to the last received Node.
Spans []*v11.Span `protobuf:"bytes,2,rep,name=spans,proto3" json:"spans,omitempty"`
// The resource for the spans in this message that do not have an explicit
// resource set.
// If unset, the most recently set resource in the RPC stream applies. It is
// valid to never be set within a stream, e.g. when no resource info is known.
Resource *v12.Resource `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ExportTraceServiceRequest) Descriptor ¶
func (*ExportTraceServiceRequest) Descriptor() ([]byte, []int)
func (*ExportTraceServiceRequest) GetNode ¶
func (m *ExportTraceServiceRequest) GetNode() *v1.Node
func (*ExportTraceServiceRequest) GetResource ¶
func (m *ExportTraceServiceRequest) GetResource() *v12.Resource
func (*ExportTraceServiceRequest) GetSpans ¶
func (m *ExportTraceServiceRequest) GetSpans() []*v11.Span
func (*ExportTraceServiceRequest) ProtoMessage ¶
func (*ExportTraceServiceRequest) ProtoMessage()
func (*ExportTraceServiceRequest) Reset ¶
func (m *ExportTraceServiceRequest) Reset()
func (*ExportTraceServiceRequest) String ¶
func (m *ExportTraceServiceRequest) String() string
func (*ExportTraceServiceRequest) XXX_DiscardUnknown ¶
func (m *ExportTraceServiceRequest) XXX_DiscardUnknown()
func (*ExportTraceServiceRequest) XXX_Marshal ¶
func (m *ExportTraceServiceRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ExportTraceServiceRequest) XXX_Merge ¶
func (m *ExportTraceServiceRequest) XXX_Merge(src proto.Message)
func (*ExportTraceServiceRequest) XXX_Size ¶
func (m *ExportTraceServiceRequest) XXX_Size() int
func (*ExportTraceServiceRequest) XXX_Unmarshal ¶
func (m *ExportTraceServiceRequest) XXX_Unmarshal(b []byte) error
type ExportTraceServiceResponse ¶
type ExportTraceServiceResponse struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ExportTraceServiceResponse) Descriptor ¶
func (*ExportTraceServiceResponse) Descriptor() ([]byte, []int)
func (*ExportTraceServiceResponse) ProtoMessage ¶
func (*ExportTraceServiceResponse) ProtoMessage()
func (*ExportTraceServiceResponse) Reset ¶
func (m *ExportTraceServiceResponse) Reset()
func (*ExportTraceServiceResponse) String ¶
func (m *ExportTraceServiceResponse) String() string
func (*ExportTraceServiceResponse) XXX_DiscardUnknown ¶
func (m *ExportTraceServiceResponse) XXX_DiscardUnknown()
func (*ExportTraceServiceResponse) XXX_Marshal ¶
func (m *ExportTraceServiceResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ExportTraceServiceResponse) XXX_Merge ¶
func (m *ExportTraceServiceResponse) XXX_Merge(src proto.Message)
func (*ExportTraceServiceResponse) XXX_Size ¶
func (m *ExportTraceServiceResponse) XXX_Size() int
func (*ExportTraceServiceResponse) XXX_Unmarshal ¶
func (m *ExportTraceServiceResponse) XXX_Unmarshal(b []byte) error
type UpdatedLibraryConfig ¶
type UpdatedLibraryConfig struct {
// This field is ignored when the RPC is used to configure only one Application.
// This is required only in the first message on the stream or if the
// previous sent UpdatedLibraryConfig message has a different Node.
Node *v1.Node `protobuf:"bytes,1,opt,name=node,proto3" json:"node,omitempty"`
// Requested updated configuration.
Config *v11.TraceConfig `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*UpdatedLibraryConfig) Descriptor ¶
func (*UpdatedLibraryConfig) Descriptor() ([]byte, []int)
func (*UpdatedLibraryConfig) GetConfig ¶
func (m *UpdatedLibraryConfig) GetConfig() *v11.TraceConfig
func (*UpdatedLibraryConfig) GetNode ¶
func (m *UpdatedLibraryConfig) GetNode() *v1.Node
func (*UpdatedLibraryConfig) ProtoMessage ¶
func (*UpdatedLibraryConfig) ProtoMessage()
func (*UpdatedLibraryConfig) Reset ¶
func (m *UpdatedLibraryConfig) Reset()
func (*UpdatedLibraryConfig) String ¶
func (m *UpdatedLibraryConfig) String() string
func (*UpdatedLibraryConfig) XXX_DiscardUnknown ¶
func (m *UpdatedLibraryConfig) XXX_DiscardUnknown()
func (*UpdatedLibraryConfig) XXX_Marshal ¶
func (m *UpdatedLibraryConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*UpdatedLibraryConfig) XXX_Merge ¶
func (m *UpdatedLibraryConfig) XXX_Merge(src proto.Message)
func (*UpdatedLibraryConfig) XXX_Size ¶
func (m *UpdatedLibraryConfig) XXX_Size() int
func (*UpdatedLibraryConfig) XXX_Unmarshal ¶
func (m *UpdatedLibraryConfig) XXX_Unmarshal(b []byte) error
Click to show internal directories.
Click to hide internal directories.